@@ -139,7 +139,7 @@ class CloudPods:
             return None
 
     @enter_and_leave_function
-    def create_server_by_guest_image(self,guest_image_id,disk_image_id,arch, disk_size, disks, nets_list, vm_name, sku="",count=1,reset_new_password="",hypervisor="kvm",bios="bios",host_id=""):
+    def create_server_by_guest_image(self,guest_image_id,disk_image_id,arch, disk_size, disks, nets_list, vm_name, sku="",count=1,reset_new_password="",hypervisor="kvm",bios="bios",cpu=256,mem=2097152):
         nets=[{"network": net} for net in nets_list]
         server = {
             "auto_start": True,
@@ -168,17 +168,12 @@ class CloudPods:
                 disk["medium"] = "ssd"
                 server["disks"].append(disk)
         if hypervisor == "baremetal":
-            if not host_id:
-                log.error("Failed to create server: Error. err msg is host_id is empty")
-                return None
-            rs=self.get_host_spec(host_id)
-
             server["disks"] = [
                         {"size":40960,"image_id":guest_image_id},
                         {"size":-1,"fs":"ext4","mountpoint":"/opt/cloud/workspace"}
                       ]
-            server["vcpu_count"]=rs["host"]["cpu"]
-            server["vmem_size"]=rs["host"]["mem"]
+            server["vcpu_count"]=cpu
+            server["vmem_size"]=mem
             server["baremetal_disk_configs"]=[
                         {"conf":"none","driver":"PCIE","count":1,"range":[0],"adapter":0,"type":"ssd"}
                       ]
@@ -358,7 +353,7 @@ if __name__ == '__main__':
     # cloudpods = CloudPods('https://10.30.18.1:30500/v3','admin','jSj@2008')
     # server_ip = cloudpods.get_server_ip("e3b76ec7-c4f9-4065-8ce2-9d833b51368c")
     # print(server_ip)
-    # cloudpods = CloudPods('https://10.240.30.110:30500/v3', 'admin', 'jSj@2008')
+    cloudpods = CloudPods('https://10.240.30.110:30500/v3', 'admin', 'jSj@2008')
     # rs=cloudpods.get_baremetal_hosts()
     # print(rs)
     # print(len(rs["hosts"]))
@@ -378,5 +373,18 @@ if __name__ == '__main__':
     #                                           host_id="8bb7f77c-d3bf-432b-85e8-8094ba0e8cd5"
     #                                           )
     # print(rs)
+    # rs = cloudpods.create_server_by_guest_image("8572ed8a-6ffe-451a-80ac-c04da95e777f",
+    #                                             "1fdfbc15-e319-4f59-8e2b-cc45bc3517cb",
+    #                                             "x86_64", 20480, [20], ["265005a2-b3a4-42e3-8154-471bdd694487"],
+    #                                             "demo2", hypervisor="baremetal", bios="UEFI"
+    #                                             )
+    # print(rs)
+    # rs=cloudpods.get_host_spec("25ca9007-111b-401e-82a0-34a4d208805b")
+    # print(rs)
+    # print(rs["host"]["cpu"])
+    # print(rs["host"]["mem"])
+    # rs = cloudpods.get_host_spec("3bf62f0b-d231-438e-8212-25f8c35f4b6f")
+    # print(rs["host"]["cpu"])
+    # print(rs["host"]["mem"])
     pass
 
